@@ -69,6 +69,32 @@ def realized(widget):
         Gtk.main_iteration()
 
 
+@unittest.skipUnless(Gtk, 'Gtk not available')
+def test_freeze_child_notif():
+
+    events = []
+
+    def on_notify(widget, spec):
+        events.append(spec.name)
+
+    b = Gtk.Box()
+    c = Gtk.Button()
+    c.connect("child-notify", on_notify)
+    c.freeze_child_notify()
+    b.pack_start(c, True, True, 0)
+    b.child_set_property(c, "expand", False)
+    b.child_set_property(c, "expand", True)
+    c.thaw_child_notify()
+    assert events.count("expand") == 1
+    del events[:]
+
+    with c.freeze_child_notify():
+        b.child_set_property(c, "expand", True)
+        b.child_set_property(c, "expand", False)
+
+    assert events.count("expand") == 1
+
+
 @unittest.skipUnless(Gtk, 'Gtk not available')
 def test_wrapper_toggle_refs():
     class MyButton(Gtk.Button):
@@ -796,6 +822,30 @@ class TestBuilder(unittest.TestCase):
                             []),
         }
 
+    def test_add_from_string(self):
+        builder = Gtk.Builder()
+        builder.add_from_string(u"")
+        builder.add_from_string("")
+
+        def get_example(string):
+            return u"""\
+<interface>
+  <menu id="appmenu">
+    <section>
+      <item>
+        <attribute name="label">%s</attribute>
+      </item>
+    </section>
+  </menu>
+</interface>""" % string
+
+        builder.add_from_string(get_example(u"ä" * 1000))
+
+        builder = Gtk.Builder()
+        builder.add_objects_from_string(u"", [''])
+        builder.add_objects_from_string("", [''])
+        builder.add_objects_from_string(get_example(u"ä" * 1000), [''])
+
     def test_extract_handler_and_args_object(self):
         class Obj():
             pass
